@@ -10,14 +10,12 @@ our @ISA = qw(Exporter);
 
 our %EXPORT_TAGS = (
     'all' => [
-        qw(check BIDIRULE_UNKNOWN BIDIRULE_LTR BIDIRULE_RTL
-           BIDIRULE_AVOIDED BIDIRULE_DISALLOWED)
-    ]
+        qw(check BIDIRULE_RTL BIDIRULE_LTR BIDIRULE_NOTBIDI BIDIRULE_INVALID)]
 );
 
 our @EXPORT_OK = @{$EXPORT_TAGS{'all'}};
 
-our $VERSION    = '0.01';
+our $VERSION    = '0.02';
 our $XS_VERSION = $VERSION;
 $VERSION = eval $VERSION;    # see L<perlmodstyle>
 
@@ -46,11 +44,11 @@ RFC 5893.
 
 Note that the word "UTF-8" in this document is used in its proper meaning.
 
-=head1 Function
+=head2 Functions
 
 =over
 
-=item check ( $string )
+=item check ( $string, [ $strict ] )
 
 Check if a string satisfys BiDi Rule.
 
@@ -65,14 +63,31 @@ A string to be checked, Unicode string or bytestring.
 Note that bytestring won't be upgraded to Unicode string but will be treated
 as UTF-8 sequence.
 
+=item $strict
+
+If C<0> is specified, won't perform following checks if the string does not
+contain right-to-left characters and is not BiDi label:
+
+=over
+
+=item *
+
+String does not begin with nonspacing mark.
+
+=item *
+
+String does not contain formatting characters, space characters and
+line separators.
+
+=back
+
 =back
 
 Returns:
 
 In scalar context:
-Direction of string, C<BIDIRULE_UNKNOWN> (C<0>), C<BIDIRULE_LTR> or
-C<BIDIRULE_RTL>, if it satisfys the rule.
-Otherwise C<undef>.
+One of C<BIDIRULE_RTL>, C<BIDIRULE_LTR> and C<BIDIRULE_NOTBIDI>
+(see L</Constants>), or C<undef>.
 
 In array context:
 A list of pairs describing detail of result with these keys:
@@ -104,6 +119,11 @@ It is undefined for invalid sequence.
 Unicode scalar value of the first character of substring,
 when C<length> item is set.
 
+=item C<unsafe>
+
+If disallowed substring contains formatting character, true value is set.
+Such character can cause problem to display.
+
 =back
 
 =item Unicode::BiDiRule::UnicodeVersion()
@@ -115,23 +135,26 @@ It should be the same as Unicode::UCD::UnicodeVersion().
 
 =head2 Constants
 
+Possible results of checking.
+
 =over
 
-=item C<BIDIRULE_UNKNOWN>
-
-=item C<BIDIRULE_LTR>
-
 =item C<BIDIRULE_RTL>
 
-=item C<BIDIRULE_AVOIDED>
+String is RTL label.
 
-=item C<BIDIRULE_DISALLOWED>
+=item C<BIDIRULE_LTR>
 
-Possible results of checking.
-C<BIDIRULE_UNKNOWN> indicates that string was empty and its direction was not
-determined.
-C<BIDIRULE_AVOIDED> indicates disallowed characters are used for explicit
-dictionality formatting so that they can cause problem to display.
+String is LTR label.
+
+=item C<BIDIRULE_NOTBIDI> (C<0>)
+
+String does not contain right-to-left characters but is not BiDi label,
+neither RTL label nor LTR label.
+
+=item C<BIDIRULE_INVALID>
+
+String does not satisfy the rule.
 
 =back
 
@@ -171,9 +194,8 @@ Table below lists implemented Unicode version by each Perl version.
 
 =item *
 
-LDH labels, strings consisting of ASCII graphic characters only,
-may not always satisfy BiDi Rule.
-They should be checked using another rule.
+The string which is not BiDi label, neither RTL label nor LTR label,
+may not always be invalid.  It should be checked by another rule.
 
 =back
 
